CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
38 lines
1.9 KiB
Plaintext
38 lines
1.9 KiB
Plaintext
// Test the __declspec spellings of CUDA attributes.
|
|
//
|
|
// RUN: %clang_cc1 -fsyntax-only -fms-extensions -verify %s
|
|
// RUN: %clang_cc1 -fsyntax-only -fms-extensions -fcuda-is-device -verify %s
|
|
// Now pretend that we're compiling a C file. There should be warnings.
|
|
// RUN: %clang_cc1 -DEXPECT_WARNINGS -fms-extensions -fsyntax-only -verify -x c %s
|
|
|
|
#if defined(EXPECT_WARNINGS)
|
|
// expected-warning@+15 {{'__device__' attribute ignored}}
|
|
// expected-warning@+15 {{'__global__' attribute ignored}}
|
|
// expected-warning@+15 {{'__constant__' attribute ignored}}
|
|
// expected-warning@+15 {{'__shared__' attribute ignored}}
|
|
// expected-warning@+15 {{'__host__' attribute ignored}}
|
|
// expected-warning@+20 {{'__device_builtin_surface_type__' attribute ignored}}
|
|
// expected-warning@+20 {{'__device_builtin_texture_type__' attribute ignored}}
|
|
//
|
|
// (Currently we don't for the other attributes. They are implemented with
|
|
// IgnoredAttr, which is ignored irrespective of any LangOpts.)
|
|
#else
|
|
// expected-warning@+14 {{'__device_builtin_surface_type__' attribute only applies to classes}}
|
|
// expected-warning@+14 {{'__device_builtin_texture_type__' attribute only applies to classes}}
|
|
#endif
|
|
|
|
__declspec(__device__) void f_device(void);
|
|
__declspec(__global__) void f_global(void);
|
|
__declspec(__constant__) int* g_constant;
|
|
__declspec(__shared__) float *g_shared;
|
|
__declspec(__host__) void f_host(void);
|
|
__declspec(__device_builtin__) void f_device_builtin(void);
|
|
typedef __declspec(__device_builtin__) const void *t_device_builtin;
|
|
enum __declspec(__device_builtin__) e_device_builtin {E};
|
|
__declspec(__device_builtin__) int v_device_builtin;
|
|
__declspec(__cudart_builtin__) void f_cudart_builtin(void);
|
|
__declspec(__device_builtin_surface_type__) unsigned long long surface_var;
|
|
__declspec(__device_builtin_texture_type__) unsigned long long texture_var;
|
|
|
|
// Note that there's no __declspec spelling of nv_weak.
|